@@ -1,27 +1,40 @@
 import logging
-import os
 from typing import TYPE_CHECKING, List, Optional
 
+from funcy import once_per_args
+
+from dvc.render.utils import match_renderers, render
+
 logger = logging.getLogger(__name__)
 
 if TYPE_CHECKING:
     from dvc.output import Output
-    from dvc.path_info import PathInfo
     from dvc.repo import Repo
 
 
+@once_per_args
+def webbrowser_open(url: str) -> int:
+    from dvc.ui import ui
+
+    return ui.open_browser(url)
+
+
 def create_summary(out):
     assert out.live and out.live["html"]
 
-    metrics, plots = out.repo.live.show(str(out.path_info))
+    metrics, plots = out.repo.live.show(out.fs_path)
 
-    html_path = out.path_info.with_suffix(".html")
+    html_path = out.fs_path + "_dvc_plots"
 
-    out.repo.plots.write_html(html_path, plots, metrics)
-    logger.info(f"\nfile://{os.path.abspath(html_path)}")
+    renderers = match_renderers(plots, out.repo.plots.templates)
+    index_path = render(
+        out.repo, renderers, metrics=metrics, path=html_path, refresh_seconds=5
+    )
+    if out.repo.config["plots"].get("auto_open", False):
+        webbrowser_open(index_path)
 
 
-def summary_path_info(out: "Output") -> Optional["PathInfo"]:
+def summary_fs_path(out: "Output") -> Optional[str]:
     from dvc.output import Output
 
     assert out.live
@@ -29,7 +42,7 @@ def summary_path_info(out: "Output") -> Optional["PathInfo"]:
     if isinstance(out.live, dict):
         has_summary = out.live.get(Output.PARAM_LIVE_SUMMARY, True)
     if has_summary:
-        return out.path_info.with_suffix(".json")
+        return out.fs.path.with_suffix(out.fs_path, ".json")
     return None
 
 
