@@ -6,11 +6,10 @@ from itertools import chain
 from funcy import cached_property, get_in, lcat, once, project
 
 from dvc import dependency, output
+from dvc.data.meta import Meta
 from dvc.hash_info import HashInfo
-from dvc.objects.meta import Meta
 from dvc.parsing import FOREACH_KWD, JOIN, DataResolver, EntryNotFound
 from dvc.parsing.versions import LOCKFILE_VERSION
-from dvc.path_info import PathInfo
 
 from . import PipelineStage, Stage, loads_from
 from .exceptions import StageNameUnspecified, StageNotFound
@@ -36,7 +35,7 @@ class StageLoader(Mapping):
 
     @cached_property
     def resolver(self):
-        wdir = PathInfo(self.dvcfile.path).parent
+        wdir = self.repo.fs.path.parent(self.dvcfile.path)
         return DataResolver(self.repo, wdir, self.data)
 
     @cached_property
@@ -69,7 +68,6 @@ class StageLoader(Mapping):
             info = get_in(checksums, [key, path], {})
             info = info.copy()
             info.pop("path", None)
-            item.isexec = info.pop("isexec", None)
             item.meta = Meta.from_dict(info)
             item.hash_info = HashInfo.from_dict(info)
 
